==> projectx-sdk-1.0.72-sources.jar: cn/com/duiba/projectx/sdk/component/grade/dto/GradeResult.java <==
package cn.com.duiba.projectx.sdk.component.grade.dto;

import cn.com.duiba.projectx.sdk.component.base.OptionResult;

import java.util.List;

public class GradeResult {

    /**
     * 当前时间
     */
    private Long timestamp = System.currentTimeMillis();

    /**
     * 组件开始时间
     */
    private Long startTimestamp;

    /**
     * 组件结束时间
     */
    private Long endTimestamp;

    /**
     * 当前经验值
     */
    private Long score;

    /**
     * 当前等级ID
     */
    private Integer currentGradeId;

    /**
     * 当前等级标识
     */
    private String currentGradeCode;

    /**
     * 当前等级名称
     */
    private String currentGradeName;

    /**
     * 当前等级配置奖品列表
     */
    private List<OptionResult> currentOptions;

    /**
     * 当前等级货币产量
     */
    private List<GradeSpProduce> currentGradeSpProduce;

    /**
     * 最大等级ID
     */
    private Integer maxGradeId;

    /**
     * 最大等级标识
     */
    private String maxGradeCode;

    /**
     * 最大等级名称
     */
    private String maxGradeName;

    /**
     * 距离下一等级所需经验值
     */
    private Long nextNeedScore;

    /**
     * 下个等级配置奖品列表
     */
    private List<OptionResult> nextOptions;

    /**
     * 未领取的奖品列表, 奖品详情
     */
    private List<GradeOptions> notOptions;

    /**
     * 未领取的奖品列表, 等级ID
     */
    private List<Integer> notGradeIds;

    /**
     * 是否升级
     */
    private boolean upGrade;

    private String extra;

    public Long getTimestamp() {
        return timestamp;
    }

    public void setTimestamp(Long timestamp) {
        this.timestamp = timestamp;
    }

    public Long getStartTimestamp() {
        return startTimestamp;
    }

    public void setStartTimestamp(Long startTimestamp) {
        this.startTimestamp = startTimestamp;
    }

    public Long getEndTimestamp() {
        return endTimestamp;
    }

    public void setEndTimestamp(Long endTimestamp) {
        this.endTimestamp = endTimestamp;
    }

    public Long getScore() {
        return score;
    }

    public void setScore(Long score) {
        this.score = score;
    }

    public Integer getCurrentGradeId() {
        return currentGradeId;
    }

    public void setCurrentGradeId(Integer currentGradeId) {
        this.currentGradeId = currentGradeId;
    }

    public String getCurrentGradeCode() {
        return currentGradeCode;
    }

    public void setCurrentGradeCode(String currentGradeCode) {
        this.currentGradeCode = currentGradeCode;
    }

    public String getCurrentGradeName() {
        return currentGradeName;
    }

    public void setCurrentGradeName(String currentGradeName) {
        this.currentGradeName = currentGradeName;
    }

    public List<OptionResult> getCurrentOptions() {
        return currentOptions;
    }

    public void setCurrentOptions(List<OptionResult> currentOptions) {
        this.currentOptions = currentOptions;
    }

    public List<GradeSpProduce> getCurrentGradeSpProduce() {
        return currentGradeSpProduce;
    }

    public void setCurrentGradeSpProduce(List<GradeSpProduce> currentGradeSpProduce) {
        this.currentGradeSpProduce = currentGradeSpProduce;
    }

    public Integer getMaxGradeId() {
        return maxGradeId;
    }

    public void setMaxGradeId(Integer maxGradeId) {
        this.maxGradeId = maxGradeId;
    }

    public String getMaxGradeCode() {
        return maxGradeCode;
    }

    public void setMaxGradeCode(String maxGradeCode) {
        this.maxGradeCode = maxGradeCode;
    }

    public String getMaxGradeName() {
        return maxGradeName;
    }

    public void setMaxGradeName(String maxGradeName) {
        this.maxGradeName = maxGradeName;
    }

    public Long getNextNeedScore() {
        return nextNeedScore;
    }

    public void setNextNeedScore(Long nextNeedScore) {
        this.nextNeedScore = nextNeedScore;
    }

    public List<OptionResult> getNextOptions() {
        return nextOptions;
    }

    public void setNextOptions(List<OptionResult> nextOptions) {
        this.nextOptions = nextOptions;
    }

    public List<GradeOptions> getNotOptions() {
        return notOptions;
    }

    public void setNotOptions(List<GradeOptions> notOptions) {
        this.notOptions = notOptions;
    }

    public List<Integer> getNotGradeIds() {
        return notGradeIds;
    }

    public void setNotGradeIds(List<Integer> notGradeIds) {
        this.notGradeIds = notGradeIds;
    }

    public boolean isUpGrade() {
        return upGrade;
    }

    public void setUpGrade(boolean upGrade) {
        this.upGrade = upGrade;
    }

    public String getExtra() {
        return extra;
    }

    public void setExtra(String extra) {
        this.extra = extra;
    }
}

==> projectx-sdk-1.0.81-sources.jar: cn/com/duiba/projectx/sdk/component/grade/dto/GradeResult.java <==
package cn.com.duiba.projectx.sdk.component.grade.dto;

import cn.com.duiba.projectx.sdk.component.base.OptionResult;

import java.util.List;

public class GradeResult {

    /**
     * 当前时间
     */
    private Long timestamp = System.currentTimeMillis();

    /**
     * 组件开始时间
     */
    private Long startTimestamp;

    /**
     * 组件结束时间
     */
    private Long endTimestamp;

    /**
     * 当前经验值
     */
    private Long score;

    /**
     * 当前等级ID
     */
    private Integer currentGradeId;

    /**
     * 当前等级标识
     */
    private String currentGradeCode;

    /**
     * 当前等级名称
     */
    private String currentGradeName;

    /**
     * 当前等级配置奖品列表
     */
    private List<OptionResult> currentOptions;

    /**
     * 当前等级货币产量
     */
    private List<GradeSpProduce> currentGradeSpProduce;

    /**
     * 最大等级ID
     */
    private Integer maxGradeId;

    /**
     * 最大等级标识
     */
    private String maxGradeCode;

    /**
     * 最大等级名称
     */
    private String maxGradeName;

    /**
     * 下一等级ID
     */
    private Integer nextGradeId;

    /**
     * 下一等级标识
     */
    private String nextGradeCode;

    /**
     * 下一等级名称
     */
    private String nextGradeName;

    /**
     * 距离下一等级所需经验值
     */
    private Long nextNeedScore;

    /**
     * 下个等级配置奖品列表
     */
    private List<OptionResult> nextOptions;

    /**
     * 未领取的奖品列表, 奖品详情
     */
    private List<GradeOptions> notOptions;

    /**
     * 未领取的奖品列表, 等级ID
     */
    private List<Integer> notGradeIds;

    /**
     * 是否升级
     */
    private boolean upGrade;

    private String extra;

    public Long getTimestamp() {
        return timestamp;
    }

    public void setTimestamp(Long timestamp) {
        this.timestamp = timestamp;
    }

    public Long getStartTimestamp() {
        return startTimestamp;
    }

    public void setStartTimestamp(Long startTimestamp) {
        this.startTimestamp = startTimestamp;
    }

    public Long getEndTimestamp() {
        return endTimestamp;
    }

    public void setEndTimestamp(Long endTimestamp) {
        this.endTimestamp = endTimestamp;
    }

    public Long getScore() {
        return score;
    }

    public void setScore(Long score) {
        this.score = score;
    }

    public Integer getCurrentGradeId() {
        return currentGradeId;
    }

    public void setCurrentGradeId(Integer currentGradeId) {
        this.currentGradeId = currentGradeId;
    }

    public String getCurrentGradeCode() {
        return currentGradeCode;
    }

    public void setCurrentGradeCode(String currentGradeCode) {
        this.currentGradeCode = currentGradeCode;
    }

    public String getCurrentGradeName() {
        return currentGradeName;
    }

    public void setCurrentGradeName(String currentGradeName) {
        this.currentGradeName = currentGradeName;
    }

    public List<OptionResult> getCurrentOptions() {
        return currentOptions;
    }

    public void setCurrentOptions(List<OptionResult> currentOptions) {
        this.currentOptions = currentOptions;
    }

    public List<GradeSpProduce> getCurrentGradeSpProduce() {
        return currentGradeSpProduce;
    }

    public void setCurrentGradeSpProduce(List<GradeSpProduce> currentGradeSpProduce) {
        this.currentGradeSpProduce = currentGradeSpProduce;
    }

    public Integer getMaxGradeId() {
        return maxGradeId;
    }

    public void setMaxGradeId(Integer maxGradeId) {
        this.maxGradeId = maxGradeId;
    }

    public String getMaxGradeCode() {
        return maxGradeCode;
    }

    public void setMaxGradeCode(String maxGradeCode) {
        this.maxGradeCode = maxGradeCode;
    }

    public String getMaxGradeName() {
        return maxGradeName;
    }

    public void setMaxGradeName(String maxGradeName) {
        this.maxGradeName = maxGradeName;
    }

    public Long getNextNeedScore() {
        return nextNeedScore;
    }

    public void setNextNeedScore(Long nextNeedScore) {
        this.nextNeedScore = nextNeedScore;
    }

    public List<OptionResult> getNextOptions() {
        return nextOptions;
    }

    public void setNextOptions(List<OptionResult> nextOptions) {
        this.nextOptions = nextOptions;
    }

    public List<GradeOptions> getNotOptions() {
        return notOptions;
    }

    public void setNotOptions(List<GradeOptions> notOptions) {
        this.notOptions = notOptions;
    }

    public List<Integer> getNotGradeIds() {
        return notGradeIds;
    }

    public void setNotGradeIds(List<Integer> notGradeIds) {
        this.notGradeIds = notGradeIds;
    }

    public boolean isUpGrade() {
        return upGrade;
    }

    public void setUpGrade(boolean upGrade) {
        this.upGrade = upGrade;
    }

    public String getExtra() {
        return extra;
    }

    public void setExtra(String extra) {
        this.extra = extra;
    }

    public Integer getNextGradeId() {
        return nextGradeId;
    }

    public void setNextGradeId(Integer nextGradeId) {
        this.nextGradeId = nextGradeId;
    }

    public String getNextGradeCode() {
        return nextGradeCode;
    }

    public void setNextGradeCode(String nextGradeCode) {
        this.nextGradeCode = nextGradeCode;
    }

    public String getNextGradeName() {
        return nextGradeName;
    }

    public void setNextGradeName(String nextGradeName) {
        this.nextGradeName = nextGradeName;
    }
}
